
/**********************************************************************************
 Persistence of Vision Ray Tracer Scene Description File
 File name   : EP_camera macro.pov
 Version     : 3.6.1c / MegaPOV 1.21
 Description : Read the documentation in: "35mm Camera Macros Version 1.rtf"
               
 Date        : 16 March 2009
 Author      : Edouard Poor
 E-mail      : p.b.i. (35mm Camera Macros)
 
 Copyright (C) 2009. All rights reserved.
**********************************************************************************/

// Render settings (right-click on a line below):
// +w640 +h640 +a0.3 +am2

#version 3.7;

#default {pigment {rgb <1,0,0>}}
#default {finish {ambient 0 diffuse 1}}

#include "colors.inc"
#include "transforms.inc"
#include "Camera35mm.inc"

global_settings {
  assumed_gamma 1.0
}

//===============================================================================================
#declare Sphere =
sphere {
  0.0, 40
  texture {
    pigment {
      radial
      frequency 4
      color_map {
        [0.00 color rgb <1.0,0.4,0.2> ]
        [0.33 color rgb <1.0,0.4,0.2> ]
        [0.33 color rgb <0.2,0.4,1.0> ]
        [0.66 color rgb <0.2,0.4,1.0> ]
        [0.66 color rgb <0.4,1.0,0.2> ]
        [1.00 color rgb <0.4,1.0,0.2> ]
      }
    }
    finish{
      specular 0.6
    }
  }
  scale 1
}

object {Sphere
  translate <-90, 0, -240>
}

object {Sphere
  translate <-60, 0, -160>
}

object {Sphere
  translate <-30, 0, -80>
}

object {Sphere
  rotate 90*z
  translate <0, 0, 0>
}

object {Sphere
  translate <30, 0, 80>
}

object {Sphere
  translate <60, 0, 160>
}

object {Sphere
  translate <90, 0, 240>
}




object {Sphere
  translate <-100, 0, 1000>
}

object {Sphere
  translate <0, 0, 5000>
}

object {Sphere
  translate <1000, 0, 10000>
}

//===============================================================================================

#declare CamLoc = <0.0, 70.0, -350.0>;
#declare CamEye = <0.0, 70.0, 0.0>;	//= focal point

#declare FocalObj =
cylinder { 
  <0, 0, 0>, <0, 10, 0>, 1
  pigment {rgb <1,0,0>}
  translate CamEye
}

//object {FocalObj}

/*
Standard full-stop f-number scale (Including aperture value AV):
 AV 	-2 	  -1 	   0 	   1 	  2 	 3 	  4 	 5 	  6 	7 	8 	9 	10 	11 	12 	13 	14
f/# 	0.5 	0.7 	1.0 	1.4 	2 	2.8 	4 	5.6 	8 	11 	16 	22 	32 	45 	64 	90 	128

Typical one-half-stop f-number scale
f/# 	1.0 	1.2 	1.4 	1.7 	2 	2.4 	2.8 	3.3 	4 	4.8 	5.6 	6.7 	8 	9.5 	11 	13 	16 	19 	22

Typical one-third-stop f-number scale
f/# 	1.0 	1.1 	1.2 	1.4 	1.6 	1.8 	2 	2.2 	2.5 	2.8 	3.2 	3.5 	4 	4.5 	5.0 	5.6 	6.3 	7.1 	8 	9 	10 	11 	13 	14 	16 	18 	20 	22

Typical one-quarter-stop f-number scale[2]
f/# 	1.8 	2 	2.2 	2.4 	2.6 	2.8 	3.2 	3.4 	3.7 	4 	4.4 	4.8 	5.2 	5.6 	6.2 	6.7 	7.3 	8 	8.7 	9.5 	10 	11 	12 	14 	15 	16 	17 	19 	21 	22

Typical focal lengths:
      28  50  70  135  210 
*/

// Cameras:
// =======
//Camera35mm_SetFocalSamples( n )
//  Camera35mm_SetFocalSamples( 100 )

//Camera35mm_SetFocalVariance( n )
//  Camera35mm_SetFocalVariance( 1/10000 )
    
//Camera35mm_NoBlur( cam_pos, look_pos, focal_length, fstop )
//  Camera35mm_NoBlur( CamLoc, CamEye, 50, 8 )
  
//Camera35mm( cam_pos, look_pos, focal_length, fstop  )
//  Camera35mm(CamLoc, CamEye, 28, 4 )

//Camera35mm_Point( cam_pos, look_pos, focal_pos, focal_length, fstop )
Camera35mm_Point(CamLoc, CamEye, <0, 0, 0>, 50, 8 )

//Camera35mm_Distance( cam_pos, look_pos, focal_distance, focal_length, fstop )
//Camera35mm_Distance(CamLoc, CamEye, 400, 50, 8 )

//Camera35mm_SetCircleOfConfusion( n )
//Camera35mm_Hyperfocal( cam_pos, look_pos, focal_length, fstop )
//Camera35mm_Hyperfocal(CamLoc, CamEye, 50, 4)

//Camera35mm_SetAutofocusTightness( fraction_of_screen )
Camera35mm_SetAutofocusTightness( 0.5 )
//Camera35mm_SetAutofocusSamples( num_samples )
Camera35mm_SetAutofocusSamples( 100 )
//Camera35mm_Autofocus( cam_pos, look_pos, focal_length, fstop, obj )
//Camera35mm_Autofocus( CamLoc, CamEye, 50, 8, FocalObj )

sky_sphere {
  pigment {
    gradient y
    color_map {
      [0.0 rgb <0.6,0.7,1.0>]
      [0.7 rgb <0.0,0.1,0.8>]
    }
  }
}

light_source {
  <0, 0, 0>            // light's position (translated below)
  color rgb <1, 1, 1>  // light's color
  translate <-30, 30, -30>*1000
}

light_source {
  <0, 0, 0>            // light's position (translated below)
  color rgb <1, 1, 1>*0.5  // light's color
  translate <30, 30, -30>*1000
  shadowless
  
}

// ----------------------------------------

plane {
  y, -50
  pigment { color rgb <0.7,0.5,0.3> }
}

